<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!message" line="0"/>
			<source>Authentication is required to set service startup type</source>
			<translation>Zaustavljanje zacetnega vrata storitve je zahtevano prijavljenost</translation>
		</message>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!description" line="0"/>
			<source>Set service startup type</source>
			<translation>Nastavi vrsto zacetnega vrata storitve</translation>
		</message>
	</context>
</TS>